from setuptools import setup, find_packages

setup(name='perk_mdplib',
      version='1.24.2',
      author='Marco Della Putta',
      author_email='marcodp183@gmail.com',
      url='https://grigoprg.webnode.it',
      maintainer='Marco Della Putta',
      maintainer_email='marcodp183@gmail.com',
      description='A powerful package that provide some interesting function',
      license='GNU License',
      py_modules=['perk_mdplib'],
      long_description="This package provide a several method to control the flow of the program",   
      )
